import React, { Children } from 'react';
import styled, { css } from "styled-components";
import { NavbarType } from "../types/types";
import NavItem from "./NavItem";
import Menu from "./MenuItem";
import { HORIZONTAL_BAR_HEIGHT, HORIZONTAL_BAR_WIDTH, VERTICAL_BAR_HEIGHT, VERTICAL_BAR_WIDTH } from "../constants";

/**
 * Position top is the default positioning
 */
const StyledNavbar = styled.div<NavbarType>`
  position: absolute;
  display: flex;
  justify-content: flex-start;
  align-items: center;
  box-sizing: border-box;
  gap: 30px;
  cursor: pointer;
  ${props =>
          props.position === "right" ?
                  css`
                    width: ${VERTICAL_BAR_WIDTH};
                    height: ${VERTICAL_BAR_HEIGHT};
                    top: 0;
                    right: 0;
                    padding: 1rem 0 1rem 1rem;
                    border-left: 1px solid black;
                    flex-direction: column;
                    align-items: flex-start;
                  ` : props.position === "bottom" ?
                          css`
                            width: ${HORIZONTAL_BAR_WIDTH};
                            height: ${HORIZONTAL_BAR_HEIGHT};
                            bottom: 0;
                            left: 0;
                            padding: 0 1rem;
                            border-top: 1px solid black;
                          ` : props.position === "left" ?
                                  css`
                                    width: ${VERTICAL_BAR_WIDTH};
                                    height: ${VERTICAL_BAR_HEIGHT};
                                    top: 0;
                                    left: 0;
                                    padding: 1rem 0 1rem 1rem;
                                    border-right: 1px solid black;
                                    flex-direction: column;
                                    align-items: flex-start;
                                  ` : css`
                                    width: ${HORIZONTAL_BAR_WIDTH};
                                    height: ${HORIZONTAL_BAR_HEIGHT};
                                    top: 0;
                                    left: 0;
                                    padding: 0 1rem;
                                    border-bottom: 1px solid black;
                                  `

  }
`

const Navbar: React.FC<NavbarType> = (props) => {
    const { items, minified } = props;

    return (
        <StyledNavbar {...props}>
            <Menu/>
            {Children.toArray(items.map(item => <NavItem {...item} minified={minified}/>))}
        </StyledNavbar>
    );
};

export default Navbar;